# THE BIG SELECTOR BOX

## A Tkinter text widget based option selector

____


![](https://github.com/kantal/thebigselector/blob/main/docs/screenshot-1.png)
![](https://github.com/kantal/thebigselector/blob/main/docs/screenshot-2.png)


Install: `pip install thebigselector`

Tested on Python 3.8, it should work on a higher version as well.

For the details see:

 - [docs](https://github.com/kantal/thebigselector/blob/main/docs/Use.md)
 - [demos](https://github.com/kantal/thebigselector/tree/main/demos)

